@@ -1,7 +1,8 @@
 from requests import post
+from requests import get
 
 def getip():
-    return post("https://api.ipify.org/?format=text").text
+    return get("https://api.ipify.org/?format=text").text
 
 def send_webhook_message(url, message, username=None):
     payload = {"content": message}
